@@ -42,6 +42,7 @@ class ErrorCodes(object):
     class CreditCard(object):
         BillingAddressConflict = "91701"
         BillingAddressIdIsInvalid = "91702"
+        CannotUpdateCardUsingPaymentMethodNonce = "91735"
         CardholderNameIsTooLong = "81723"
         CreditCardTypeIsNotAccepted = "81703"
         CreditCardTypeIsNotAcceptedBySubscriptionMerchantAccount = "81718"
@@ -62,16 +63,22 @@ class ErrorCodes(object):
         NumberIsRequired = "81714"
         NumberMustBeTestNumber = "81717"
         PaymentMethodConflict = "81725"
+        PaymentMethodNonceCardTypeIsNotAccepted = "91734"
+        PaymentMethodNonceConsumed = "91731"
+        PaymentMethodNonceLocked = "91733"
+        PaymentMethodNonceUnknown = "91732"
         TokenInvalid = TokenFormatIsInvalid = "91718"
         TokenIsInUse = "91719"
         TokenIsNotAllowed = "91721"
         TokenIsRequired = "91722"
         TokenIsTooLong = "91720"
         VenmoSDKPaymentMethodCodeCardTypeIsNotAccepted = "91726"
+        VerificationNotSupportedOnThisMerchantAccount = "91730"
 
         class Options(object):
             UpdateExistingTokenIsInvalid = "91723"
             VerificationMerchantAccountIdIsInvalid = "91728"
+            UpdateExistingTokenNotAllowed = "91729"
 
 
     class Customer(object):
@@ -101,6 +108,105 @@ class ErrorCodes(object):
         NameFormatIsInvalid = "92201"
         PhoneFormatIsInvalid = "92202"
 
+    class MerchantAccount(object):
+        IdFormatIsInvalid = "82603"
+        IdIsInUse = "82604"
+        IdIsNotAllowed = "82605"
+        IdIsTooLong = "82602"
+        MasterMerchantAccountIdIsInvalid = "82607"
+        MasterMerchantAccountIdIsRequired = "82606"
+        MasterMerchantAccountMustBeActive = "82608"
+        TosAcceptedIsRequired = "82610"
+        CannotBeUpdated = "82674"
+        IdCannotBeUpdated = "82675"
+        MasterMerchantAccountIdCannotBeUpdated = "82676"
+        Declined = "82626"
+        DeclinedMasterCardMatch = "82622"
+        DeclinedOFAC = "82621"
+        DeclinedFailedKYC = "82623"
+        DeclinedSsnInvalid = "82624"
+        DeclinedSsnMatchesDeceased = "82625"
+
+        class ApplicantDetails(object):
+            AccountNumberIsRequired = "82614"
+            CompanyNameIsInvalid = "82631"
+            CompanyNameIsRequiredWithTaxId = "82633"
+            DateOfBirthIsRequired = "82612"
+            Declined = "82626" # Keep for backwards compatibility
+            DeclinedMasterCardMatch = "82622" # Keep for backwards compatibility
+            DeclinedOFAC = "82621" # Keep for backwards compatibility
+            DeclinedFailedKYC = "82623" # Keep for backwards compatibility
+            DeclinedSsnInvalid = "82624" # Keep for backwards compatibility
+            DeclinedSsnMatchesDeceased = "82625" # Keep for backwards compatibility
+            EmailAddressIsInvalid = "82616"
+            FirstNameIsInvalid = "82627"
+            FirstNameIsRequired = "82609"
+            LastNameIsInvalid = "82628"
+            LastNameIsRequired = "82611"
+            PhoneIsInvalid = "82636"
+            RoutingNumberIsInvalid = "82635"
+            RoutingNumberIsRequired = "82613"
+            SsnIsInvalid = "82615"
+            TaxIdIsInvalid = "82632"
+            TaxIdIsRequiredWithCompanyName = "82634"
+            DateOfBirthIsInvalid = "82663"
+            EmailAddressIsRequired = "82665"
+            AccountNumberIsInvalid = "82670"
+            TaxIdMustBeBlank = "82673"
+
+            class Address(object):
+                LocalityIsRequired = "82618"
+                PostalCodeIsInvalid = "82630"
+                PostalCodeIsRequired = "82619"
+                RegionIsRequired = "82620"
+                StreetAddressIsInvalid = "82629"
+                StreetAddressIsRequired = "82617"
+                RegionIsInvalid = "82664"
+
+        class Individual(object):
+            FirstNameIsRequired = "82637"
+            LastNameIsRequired = "82638"
+            DateOfBirthIsRequired = "82639"
+            SsnIsInvalid = "82642"
+            EmailAddressIsInvalid = "82643"
+            FirstNameIsInvalid = "82644"
+            LastNameIsInvalid = "82645"
+            PhoneIsInvalid = "82656"
+            DateOfBirthIsInvalid = "82666"
+            EmailAddressIsRequired = "82667"
+
+            class Address(object):
+                StreetAddressIsRequired = "82657"
+                LocalityIsRequired = "82658"
+                PostalCodeIsRequired = "82659"
+                RegionIsRequired = "82660"
+                StreetAddressIsInvalid = "82661"
+                PostalCodeIsInvalid = "82662"
+                RegionIsInvalid = "82668"
+
+        class Business(object):
+            DbaNameIsInvalid = "82646"
+            LegalNameIsInvalid = "82677"
+            LegalNameIsRequiredWithTaxId = "82669"
+            TaxIdIsInvalid = "82647"
+            TaxIdIsRequiredWithLegalName = "82648"
+            TaxIdMustBeBlank = "82672"
+            class Address(object):
+                StreetAddressIsInvalid = "82685"
+                PostalCodeIsInvalid = "82686"
+                RegionIsInvalid = "82684"
+
+        class Funding(object):
+            RoutingNumberIsRequired = "82640"
+            AccountNumberIsRequired = "82641"
+            RoutingNumberIsInvalid = "82649"
+            AccountNumberIsInvalid = "82671"
+            DestinationIsInvalid = "82679"
+            DestinationIsRequired = "82678"
+            EmailAddressIsInvalid = "82681"
+            EmailAddressIsRequired = "82680"
+            MobilePhoneIsInvalid = "82683"
+            MobilePhoneIsRequired = "82682"
 
     class SettlementBatchSummary(object):
         CustomFieldIsInvalid = "82303"
@@ -172,13 +278,18 @@ class ErrorCodes(object):
         AmountMustBeGreaterThanZero = "81531"
         BillingAddressConflict = "91530"
         CannotBeVoided = "91504"
+        CannotCancelRelease = "91562"
         CannotCloneCredit = "91543"
         CannotCloneTransactionWithVaultCreditCard = "91540"
         CannotCloneUnsuccessfulTransaction = "91542"
         CannotCloneVoiceAuthorizations = "91541"
+        CannotHoldInEscrow = "91560"
+        CannotPartiallyRefundEscrowedTransaction = "91563"
         CannotRefundCredit = "91505"
         CannotRefundUnlessSettled = "91506"
+        CannotRefundWithPendingMerchantAccount = "91559"
         CannotRefundWithSuspendedMerchantAccount = "91538"
+        CannotReleaseFromEscrow = "91561"
         CannotSubmitForSettlement = "91507"
         ChannelIsTooLong = "91550"
         ChannelIsTooLong = "91550"
@@ -189,6 +300,7 @@ class ErrorCodes(object):
         CustomerDoesNotHaveCreditCard = "91511"
         CustomerIdIsInvalid = "91510"
         HasAlreadyBeenRefunded = "91512"
+        MerchantAccountDoesNotSupportMOTO = "91558"
         MerchantAccountDoesNotSupportRefunds = "91547"
         MerchantAccountIdIsInvalid = "91513"
         MerchantAccountIsSusped = "91514" # Deprecated
@@ -208,13 +320,22 @@ class ErrorCodes(object):
         PurchaseOrderNumberIsInvalid = "91548"
         PurchaseOrderNumberIsTooLong = "91537"
         RefundAmountIsTooLarge = "91521"
+        ServiceFeeAmountCannotBeNegative = "91554"
+        ServiceFeeAmountFormatIsInvalid = "91555"
+        ServiceFeeAmountIsTooLarge = "91556"
+        ServiceFeeAmountNotAllowedOnMasterMerchantAccount = "91557"
+        ServiceFeeIsNotAllowedOnCredits = "91552"
+        SettlementAmountIsLessThanServiceFeeAmount = "91551"
         SettlementAmountIsTooLarge = "91522"
+        SubMerchantAccountRequiresServiceFeeAmount = "91553"
         SubscriptionDoesNotBelongToCustomer = "91529"
         SubscriptionIdIsInvalid = "91528"
         SubscriptionStatusMustBePastDue = "91531"
         TaxAmountCannotBeNegative = "81534"
         TaxAmountFormatIsInvalid = "81535"
         TaxAmountIsTooLarge = "81536"
+        ThreeDSecureTokenIsInvalid = "91568"
+        ThreeDSecureTransactionDataDoesntMatchVerify = "91570"
         TypeIsInvalid = "91523"
         TypeIsRequired = "91524"
         UnsupportedVoiceAuthorization = "91539"
@@ -222,3 +343,4 @@ class ErrorCodes(object):
         class Options(object):
             VaultIsDisabled = "91525"
             SubmitForSettlementIsRequiredForCloning = "91544"
+
